pub(crate) fn mount_esp_at(device: &str, path: PathBuf) -> Result<MountGuard>Expand description
Mount the ESP from device at the given path and return a guard that
synchronously unmounts (and flushes) it on drop.
pub(crate) fn mount_esp_at(device: &str, path: PathBuf) -> Result<MountGuard>Mount the ESP from device at the given path and return a guard that
synchronously unmounts (and flushes) it on drop.